Jembe Web Framework
===================

Python Web Framework for builiding modern web applications, runs on top of Flask, designed with following goals:

- App is build using custom, reusable, reactive, responsive UI components;
- Developers can stay focused on "business" logic and write UI logic only for very specific use cases;
- UI Component is created by extending Python class, with simple API, and writing associated Jinja2 template; 
- Complex UI interactions can be created without or with minimal use of javascript code;
- There should be no reason to think off, consider or implement logic for:
    - Handling http request-response cycle
    - Routing
    - Handling any "low level" web/http api

Official web site https://jembe.io


License
-------


Jembe Web Framework 
Copyright (C) 2021 BlokKod <info@blokkod.me>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published
by the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.